@@ -109,7 +109,7 @@ maybe_migrate_settings (TerminalApp *app)
 #ifdef ENABLE_MIGRATION
   const char * const argv[] = { 
     TERM_LIBEXECDIR "/gnome-terminal-migration",
-#ifdef GNOME_ENABLE_DEBUG
+#ifdef ENABLE_DEBUG
     "--verbose", 
 #endif
     NULL 
@@ -235,7 +235,12 @@ terminal_app_encoding_list_notify_cb (GSettings   *settings,
   encoding->is_active = TRUE;
 
   g_settings_get (settings, key, "^as", &encodings);
-  for (i = 0; encodings[i] != NULL; ++i) {
+  for (i = 0; encodings[i] != NULL; ++i)
+    {
+      /* Pre-3.13, not supported anymore */
+      if (g_str_equal (encodings[i], "current"))
+        continue;
+
       encoding = terminal_app_ensure_encoding (app, encodings[i]);
       if (!terminal_encoding_is_valid (encoding))
         continue;
@@ -625,6 +630,25 @@ terminal_app_get_encodings (TerminalApp *app)
   return app->encodings;
 }
 
+static const char *
+charset_validated (const char *charset)
+{
+  gsize i;
+
+  if (charset == NULL)
+    goto out;
+
+  for (i = 0; charset[i] != '\0'; i++) {
+    char c = charset[i];
+    if (!(g_ascii_isalnum(c) || c == '_' || c == '-'))
+      goto out;
+  }
+
+  return charset;
+ out:
+  return "UTF-8";
+}
+
 /**
  * terminal_app_ensure_encoding:
  * @app:
@@ -635,7 +659,7 @@ terminal_app_get_encodings (TerminalApp *app)
  * @charset is not a known charset, returns a #TerminalEncoding for a
  * custom charset.
  *
- * Returns: (transfer none): a #TerminalEncoding
+ * Returns: (transfer none): a #TerminalEncoding, or %NULL
  */
 TerminalEncoding *
 terminal_app_ensure_encoding (TerminalApp *app,
@@ -643,7 +667,7 @@ terminal_app_ensure_encoding (TerminalApp *app,
 {
   TerminalEncoding *encoding;
 
-  encoding = g_hash_table_lookup (app->encodings, charset ? charset : "UTF-8");
+  encoding = g_hash_table_lookup (app->encodings, charset_validated (charset));
   if (encoding == NULL)
     {
       encoding = terminal_encoding_new (charset,
